# sync2jira

## Importer le package
```
 pip install synchros1s2
```

## Mettre à jour le package
```
 pip install --upgrade synchros1s2
```

## Remplir le fichier de config 
Déplacer le fichier de config dans votre projet de test et le remplir. 
Ce script Python configure plusieurs variables et paramètres nécessaires pour Jira. Il définit des chemins de fichiers, des formats de journalisation, des informations d'authentification et des URL Jira.



